#!/usr/bin/env node

const fs = require('fs')
const path = require('path')
const commandline = require('command-line-commands')
const columnify = require('columnify')
const validator = require('validator')
const apilogger = require('../lib/flatlog')

const helpFile = path.join(__dirname, '../asset/gwisp.txt')
const cmds = ['help', 'new', 'start', 'info']
var cmdp
try {
  cmdp = commandline(cmds)
} catch (e) {
  help()
  process.exit(1)
}

const config = require('../config')
const gwisp = require('../lib/gwisp')

const logger = apilogger({caller: 'gwisp'})

var app

// merge configuration between config file and command line arguments
if (cmdp.argv.indexOf('--verbose') >= 0) {
  config.set('verbose', 1)
}
if (cmdp.argv.indexOf('--port') >= 0) {
  var port = cmdp.argv[cmdp.argv.indexOf('--port') + 1]
  if (!port || !validator.isInt(port)) {
    logger.log('error', '--port must be number')
    process.exit(1)
  }
  config.set('port', port)
}

// choose program coresponse with command name
// in bad command name, do nothing, message and exit
switch (cmdp.command) {
  case 'help':
    help()
    break
  case 'start':
    app = gwisp(config._instance)

    app.start(function (err, res) {
      if (err) process.exit(1)
      // do not terminal process. wait for killed by other processes
    })

    break
  case 'new':
    app = gwisp(config._instance)

    app.setup(path.join(__dirname, '../asset'), function (err) {
      if (err) return process.exit(1)
      process.exit(0)
    })

    break
  case 'info':
    console.log(columnify(config._instance, {
      preserveNewLines: true,
      showHeaders: false,
      config: {
        key: {
          minWidth: 18,
          maxWidth: 18
        },
        value: {
          minWidth: 60,
          maxWidth: 60
        }
      }
    }))
    break
}

function help () {
  console.log(fs.readFileSync(helpFile).toString())
}
